@@ -2,6 +2,6 @@
 ## Plotting entropy index
 ## ======================
 
-seqHtplot <- function(seqdata, group = NULL, main = NULL, ...) {
+seqHtplot <- function(seqdata, group = NULL, main = "auto", ...) {
 	seqplot(seqdata, group=group, type="Ht", main=main, ...)
 }
